#ifndef KVKBDDRAGWIDGET_H
#define KVKBDDRAGWIDGET_H
#include <qwidget.h>
#include <qpoint.h>
#include <qevent.h>

class DragWidget : public QWidget
{
Q_OBJECT
public:
	DragWidget(QWidget *parent=0, const char *name="", WFlags f=0);
	virtual ~DragWidget();

	void setLocked(bool mode);
	const bool isLocked() const;

private:
	
	bool drag;
	

protected:
	void mouseMoveEvent ( QMouseEvent * e );
	void mousePressEvent ( QMouseEvent * e );
	void mouseReleaseEvent ( QMouseEvent * e );
	QPoint dragP;
	QPoint gpress;
	bool locked;

};

#endif

